<?php

/**
 * Wiki plugin
 *
 *
 * Created: 2007-02-17
 * Last update: 2007-03-31
 *
 * @link http://deboutv.free.fr/mantis/
 * @author DEBOUT Vincent  <deboutv@free.fr>
 */

define( 'PLUGINS_WIKI_BY_NAME', 0 );
define( 'PLUGINS_WIKI_BY_ID', 1 );
define( 'PLUGINS_WIKI_URL_TYPE_DEFAULT', PLUGINS_WIKI_BY_ID );

/**
 * Call the wiki function
 *
 * @param string $p_function The function to call
 * @param mixed $p_args_array arguments
 */
function wiki_call( $p_function, $p_args_array ) {
    $t_function = 'wiki_' . config_get( 'wiki_engine' ) . '_' . $p_function;
    return call_user_func_array( $t_function, $p_args_array );
}

/**
 * This function is used to print the template list
 * 
 */
function plugins_wiki_print_template_list() {
    $t_config = plugins_wiki_read_config();
    $t_templates = plugins_wiki_get_template_list();
    foreach( $t_templates as $t_template ) {
        echo '            <option value="' . $t_template . '"';
        if ( $t_template == $t_config['template'] ) {
            echo ' selected="selected"';
        }
        echo '>' . $t_template . '</option>' . "\n";
    }
}

/** 
 * This function returns the template list
 *
 * @return array
 */
function plugins_wiki_get_template_list() {
    $t_template_directory = dirname( dirname( dirname( dirname( __FILE__ ) ) ) ) . DIRECTORY_SEPARATOR . 'dokuwiki';
    $t_template_directory .= DIRECTORY_SEPARATOR . 'lib' . DIRECTORY_SEPARATOR . 'tpl';
    $t_dir = opendir( $t_template_directory );
    $t_template_list = array();
    while( ( $t_file = readdir( $t_dir ) ) !== false ) {
        if ( $t_file != '.' && $t_file != '..' && is_dir( $t_template_directory . DIRECTORY_SEPARATOR . $t_file ) ) {
            if ( file_exists( $t_template_directory . DIRECTORY_SEPARATOR . $t_file . DIRECTORY_SEPARATOR . 'main.php' ) ) {
                $t_template_list[] = $t_file;
            }
        }
    }
    closedir( $t_dir );
    return $t_template_list;
}

/**
 * This function is used to read the configuration
 *
 * @return array
 */
function plugins_wiki_read_config() {
    $t_file = dirname( dirname( dirname( dirname( __FILE__ ) ) ) ) . DIRECTORY_SEPARATOR . 'dokuwiki';
    $t_file .= DIRECTORY_SEPARATOR . 'conf' . DIRECTORY_SEPARATOR . 'local.php';
    $conf = array();
    $conf['template'] = 'default';
    if ( file_exists( $t_file ) ) {
        include( $t_file );
    }
    return $conf;
}

/**
 * This function is used to write the configuration
 *
 */
function plugins_wiki_write_config( $p_template, $p_administrator ) {
    $t_filename = dirname( dirname( dirname( dirname( __FILE__ ) ) ) ) . DIRECTORY_SEPARATOR . 'dokuwiki';
    $t_filename .= DIRECTORY_SEPARATOR . 'conf' . DIRECTORY_SEPARATOR . 'local.php';
    $t_conf = plugins_wiki_read_config();
    $t_conf['template'] = $p_template;
    $t_file = fopen( $t_filename, 'w' );
    fwrite( $t_file, '<?php' . "\n" );
    fwrite( $t_file, '/**' . "\n" );
    fwrite( $t_file, ' * Dokuwiki\'s Main Configuration File - Local Settings' . "\n" );
    fwrite( $t_file, ' * Auto-generated by install script' . "\n" );
    fwrite( $t_file, ' * Date: ' . date( 'r' ) . "\n" );
    fwrite( $t_file, ' */' . "\n" );
    fwrite( $t_file, '$conf[\'title\'] = \'Mantis\';' . "\n" );
    fwrite( $t_file, '$conf[\'lang\'] = \'en\';' . "\n" );
    fwrite( $t_file, '$conf[\'useacl\'] = 1;' . "\n" );
    fwrite( $t_file, '$conf[\'superuser\'] = \'' . $p_administrator . '\';' . "\n\n" );
    fwrite( $t_file, 'define( \'MANTIS_ROOT\', \'' . dirname( dirname( dirname( dirname( __FILE__ ) ) ) ) . DIRECTORY_SEPARATOR . '\' );' . "\n" );
    fwrite( $t_file, '$conf[\'template\'] = \'' . $t_conf['template'] . '\';' . "\n" );
    fwrite( $t_file, '$conf[\'authtype\'] = \'mantis\';' . "\n" );
    fwrite( $t_file, '$conf[\'defaultgroup\'] = \'VIEWER\';' . "\n\n" );
    fwrite( $t_file, '?>' . "\n" );
    fclose( $t_file );
}

/**
 * This function is used to write the user file
 *
 * @param array $p_user User info 
 */
function plugins_wiki_write_user( $p_user ) {
    $t_filename = dirname( dirname( dirname( dirname( __FILE__ ) ) ) ) . DIRECTORY_SEPARATOR . 'dokuwiki';
    $t_filename .= DIRECTORY_SEPARATOR . 'conf' . DIRECTORY_SEPARATOR . 'users.auth.php';
    $t_file = fopen( $t_filename, 'w' );
    fwrite( $t_file, '# users.auth.php' . "\n" );
    fwrite( $t_file, '# <?php exit()?>' . "\n" );
    fwrite( $t_file, '# Don\'t modify the lines above' . "\n" );
    fwrite( $t_file, '#' . "\n" );
    fwrite( $t_file, '# Userfile' . "\n" );
    fwrite( $t_file, '#' . "\n" );
    fwrite( $t_file, '# Format:' . "\n" );
    fwrite( $t_file, '#' . "\n" );
    fwrite( $t_file, '# user:MD5password:Real Name:email:groups,comma,seperated' . "\n\n\n" );
    fwrite( $t_file, 'administrator:' . $p_user['password'] . ':' . $p_user['name'] . ':' . $p_user['email'] . ':admin,user' . "\n\n" );
    fclose( $t_file );
}

/**
 * This funciton is used to read the user file
 *
 * @return array
 */
function plugins_wiki_read_user() {
    $t_filename = dirname( dirname( dirname( dirname( __FILE__ ) ) ) ) . DIRECTORY_SEPARATOR . 'dokuwiki';
    $t_filename .= DIRECTORY_SEPARATOR . 'conf' . DIRECTORY_SEPARATOR . 'users.auth.php';
    $t_file = fopen( $t_filename, 'r' );
    $t_contents = fread( $t_file, filesize( $t_filename ) );
    fclose( $t_file );
    $t_contents = explode( "\n", $t_contents );
    $t_result = array();
    foreach( $t_contents as $t_line ) {
        if ( eregi( '^administrator', $t_line ) ) {
            $t_line = explode( ':', $t_line );
            $t_result['name'] = $t_line[2];
            $t_result['email'] = $t_line[3];
            $t_result['password'] = $t_line[1];
        }
    }
    return $t_result;
}

?>
